@@ -17,7 +17,6 @@ use crate::MEDIA_SECTION_APPLICATION;
 pub mod sdp_type;
 pub mod session_description;
 
-use crate::peer::sdp::session_description::RTCSessionDescriptionSerde;
 use anyhow::Result;
 use ice::candidate::candidate_base::unmarshal_candidate;
 use ice::candidate::Candidate;
@@ -56,9 +55,7 @@ pub(crate) fn filter_track_with_ssrc(incoming_tracks: &mut Vec<TrackDetails>, ss
 }
 
 /// extract all TrackDetails from an SDP.
-pub(crate) fn track_details_from_sdp(
-    s: &sdp::session_description::SessionDescription,
-) -> Vec<TrackDetails> {
+pub(crate) fn track_details_from_sdp(s: &SessionDescription) -> Vec<TrackDetails> {
     let mut incoming_tracks = vec![];
     let mut rtx_repair_flows = HashMap::new();
 
@@ -265,11 +262,11 @@ pub(crate) struct AddDataMediaSectionParams {
 }
 
 pub(crate) async fn add_data_media_section(
-    d: sdp::session_description::SessionDescription,
+    d: SessionDescription,
     dtls_fingerprints: &[RTCDtlsFingerprint],
     candidates: &[RTCIceCandidate],
     params: AddDataMediaSectionParams,
-) -> Result<sdp::session_description::SessionDescription> {
+) -> Result<SessionDescription> {
     let mut media = MediaDescription {
         media_name: MediaName {
             media: MEDIA_SECTION_APPLICATION.to_owned(),
@@ -350,10 +347,8 @@ pub(crate) async fn populate_local_candidates(
         }
 
         Some(session_description::RTCSessionDescription {
-            serde: RTCSessionDescriptionSerde {
-                sdp_type: sd.serde.sdp_type,
-                sdp: parsed.marshal(),
-            },
+            sdp_type: sd.sdp_type,
+            sdp: parsed.marshal(),
             parsed: Some(parsed),
         })
     } else {
@@ -370,14 +365,14 @@ pub(crate) struct AddTransceiverSdpParams {
 }
 
 pub(crate) async fn add_transceiver_sdp(
-    mut d: sdp::session_description::SessionDescription,
+    mut d: SessionDescription,
     dtls_fingerprints: &[RTCDtlsFingerprint],
     media_engine: &Arc<MediaEngine>,
     ice_params: &RTCIceParameters,
     candidates: &[RTCIceCandidate],
     media_section: &MediaSection,
     params: AddTransceiverSdpParams,
-) -> Result<(sdp::session_description::SessionDescription, bool)> {
+) -> Result<(SessionDescription, bool)> {
     if media_section.transceivers.is_empty() {
         return Err(Error::ErrSDPZeroTransceivers.into());
     }
@@ -392,18 +387,15 @@ pub(crate) async fn add_transceiver_sdp(
     let transceivers = &media_section.transceivers;
     // Use the first transceiver to generate the section attributes
     let t = &transceivers[0];
-    let mut media = sdp::media_description::MediaDescription::new_jsep_media_description(
-        t.kind.to_string(),
-        vec![],
-    )
-    .with_value_attribute(ATTR_KEY_CONNECTION_SETUP.to_owned(), dtls_role.to_string())
-    .with_value_attribute(ATTR_KEY_MID.to_owned(), mid_value.clone())
-    .with_ice_credentials(
-        ice_params.username_fragment.clone(),
-        ice_params.password.clone(),
-    )
-    .with_property_attribute(ATTR_KEY_RTCPMUX.to_owned())
-    .with_property_attribute(ATTR_KEY_RTCPRSIZE.to_owned());
+    let mut media = MediaDescription::new_jsep_media_description(t.kind.to_string(), vec![])
+        .with_value_attribute(ATTR_KEY_CONNECTION_SETUP.to_owned(), dtls_role.to_string())
+        .with_value_attribute(ATTR_KEY_MID.to_owned(), mid_value.clone())
+        .with_ice_credentials(
+            ice_params.username_fragment.clone(),
+            ice_params.password.clone(),
+        )
+        .with_property_attribute(ATTR_KEY_RTCPMUX.to_owned())
+        .with_property_attribute(ATTR_KEY_RTCPRSIZE.to_owned());
 
     let codecs = t.get_codecs().await;
     for codec in &codecs {
@@ -433,7 +425,7 @@ pub(crate) async fn add_transceiver_sdp(
     }
     if codecs.is_empty() {
         // Explicitly reject track if we don't have the codec
-        d = d.with_media(sdp::media_description::MediaDescription {
+        d = d.with_media(MediaDescription {
             media_name: sdp::media_description::MediaName {
                 media: t.kind.to_string(),
                 port: RangedPort {
@@ -545,14 +537,14 @@ pub(crate) struct PopulateSdpParams {
 
 /// populate_sdp serializes a PeerConnections state into an SDP
 pub(crate) async fn populate_sdp(
-    mut d: sdp::session_description::SessionDescription,
+    mut d: SessionDescription,
     dtls_fingerprints: &[RTCDtlsFingerprint],
     media_engine: &Arc<MediaEngine>,
     candidates: &[RTCIceCandidate],
     ice_params: &RTCIceParameters,
     media_sections: &[MediaSection],
     params: PopulateSdpParams,
-) -> Result<sdp::session_description::SessionDescription> {
+) -> Result<SessionDescription> {
     let media_dtls_fingerprints = if params.media_description_fingerprint {
         dtls_fingerprints.to_vec()
     } else {
@@ -658,9 +650,7 @@ pub(crate) fn description_is_plan_b(
     Ok(false)
 }
 
-pub(crate) fn get_peer_direction(
-    media: &sdp::media_description::MediaDescription,
-) -> RTCRtpTransceiverDirection {
+pub(crate) fn get_peer_direction(media: &MediaDescription) -> RTCRtpTransceiverDirection {
     for a in &media.attributes {
         let direction = RTCRtpTransceiverDirection::from(a.key.as_str());
         if direction != RTCRtpTransceiverDirection::Unspecified {
@@ -670,9 +660,7 @@ pub(crate) fn get_peer_direction(
     RTCRtpTransceiverDirection::Unspecified
 }
 
-pub(crate) fn extract_fingerprint(
-    desc: &sdp::session_description::SessionDescription,
-) -> Result<(String, String)> {
+pub(crate) fn extract_fingerprint(desc: &SessionDescription) -> Result<(String, String)> {
     let mut fingerprints = vec![];
 
     if let Some(fingerprint) = desc.attribute("fingerprint") {
@@ -704,7 +692,7 @@ pub(crate) fn extract_fingerprint(
 }
 
 pub(crate) async fn extract_ice_details(
-    desc: &sdp::session_description::SessionDescription,
+    desc: &SessionDescription,
 ) -> Result<(String, String, Vec<RTCIceCandidate>)> {
     let mut candidates = vec![];
     let mut remote_pwds = vec![];
@@ -758,9 +746,7 @@ pub(crate) async fn extract_ice_details(
     Ok((remote_ufrags[0].clone(), remote_pwds[0].clone(), candidates))
 }
 
-pub(crate) fn have_application_media_section(
-    desc: &sdp::session_description::SessionDescription,
-) -> bool {
+pub(crate) fn have_application_media_section(desc: &SessionDescription) -> bool {
     for m in &desc.media_descriptions {
         if m.media_name.media == MEDIA_SECTION_APPLICATION {
             return true;
@@ -773,7 +759,7 @@ pub(crate) fn have_application_media_section(
 pub(crate) fn get_by_mid<'a, 'b>(
     search_mid: &'a str,
     desc: &'b session_description::RTCSessionDescription,
-) -> Option<&'b sdp::media_description::MediaDescription> {
+) -> Option<&'b MediaDescription> {
     if let Some(parsed) = &desc.parsed {
         for m in &parsed.media_descriptions {
             if let Some(mid) = m.attribute(ATTR_KEY_MID) {
@@ -789,7 +775,7 @@ pub(crate) fn get_by_mid<'a, 'b>(
 /// have_data_channel return MediaDescription with MediaName equal application
 pub(crate) fn have_data_channel(
     desc: &session_description::RTCSessionDescription,
-) -> Option<&sdp::media_description::MediaDescription> {
+) -> Option<&MediaDescription> {
     if let Some(parsed) = &desc.parsed {
         for d in &parsed.media_descriptions {
             if d.media_name.media == MEDIA_SECTION_APPLICATION {
@@ -801,9 +787,9 @@ pub(crate) fn have_data_channel(
 }
 
 pub(crate) fn codecs_from_media_description(
-    m: &sdp::media_description::MediaDescription,
+    m: &MediaDescription,
 ) -> Result<Vec<RTCRtpCodecParameters>> {
-    let s = sdp::session_description::SessionDescription {
+    let s = SessionDescription {
         media_descriptions: vec![m.clone()],
         ..Default::default()
     };
@@ -859,7 +845,7 @@ pub(crate) fn codecs_from_media_description(
 }
 
 pub(crate) fn rtp_extensions_from_media_description(
-    m: &sdp::media_description::MediaDescription,
+    m: &MediaDescription,
 ) -> Result<HashMap<String, isize>> {
     let mut out = HashMap::new();
 
@@ -883,10 +869,7 @@ pub(crate) fn rtp_extensions_from_media_description(
 /// and increments session version by one.
 /// https://tools.ietf.org/html/draft-ietf-rtcweb-jsep-25#section-5.2.2
 /// https://tools.ietf.org/html/draft-ietf-rtcweb-jsep-25#section-5.3.2
-pub(crate) fn update_sdp_origin(
-    origin: &mut Origin,
-    d: &mut sdp::session_description::SessionDescription,
-) {
+pub(crate) fn update_sdp_origin(origin: &mut Origin, d: &mut SessionDescription) {
     //TODO: if atomic.CompareAndSwapUint64(&origin.SessionVersion, 0, d.Origin.SessionVersion)
     if origin.session_version == 0 {
         // store
